Package: sars
Type: Package
Title: Fit and Compare Species-Area Relationship Models Using
        Multimodel Inference
Version: 2.1.1
Authors@R: c(person("Thomas J.", "Matthews", email = "txm676@gmail.com",
                  role = c("aut", "cre"), comment = c(ORCID = "0000-0002-7624-244X")),
            person("Francois", "Guilhaumon", email = "francois.guilhaumon@ird.fr",
                  role = c("aut"), comment = c(ORCID = "0000-0003-4707-8932")),
                  person("Kevin", "Cazelles", role = c("rev"), comment = c(ORCID = "0000-0001-6619-9874")))
Description: Implements the basic elements of the multi-model
    inference paradigm for up to twenty species-area relationship models (SAR), using simple
    R list-objects and functions, as in Triantis et al. 2012 <DOI:10.1111/j.1365-2699.2011.02652.x>.
    The package is scalable and users can easily create their own model and data objects. Additional
    SAR related functions are provided.
License: GPL-3 | file LICENSE
URL: https://github.com/txm676/sars
BugReports: https://github.com/txm676/sars/issues
Imports: graphics, nortest, stats, utils, crayon, cli, numDeriv,
        doParallel, foreach, parallel, AICcmodavg, minpack.lm,
Depends: R(>= 4.0.0)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Suggests: knitr, rmarkdown, testthat, covr, tibble
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-01-06 18:15:43 UTC; MattheTJ
Author: Thomas J. Matthews [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7624-244X>),
  Francois Guilhaumon [aut] (ORCID:
    <https://orcid.org/0000-0003-4707-8932>),
  Kevin Cazelles [rev] (ORCID: <https://orcid.org/0000-0001-6619-9874>)
Maintainer: Thomas J. Matthews <txm676@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-07 22:30:07 UTC
Built: R 4.6.0; ; 2026-04-26 10:11:25 UTC; unix
