# Generated by roxygen2: do not edit by hand

S3method(logLik,thresholdInt)
S3method(plot,coleman)
S3method(plot,habitat)
S3method(plot,multi)
S3method(plot,sars)
S3method(plot,threshold)
S3method(print,gdm)
S3method(print,sars)
S3method(print,summary.sars)
S3method(summary,sars)
export(coleman)
export(countryside_extrap)
export(display_sars_models)
export(gdm)
export(get_coef)
export(lin_pow)
export(sar_asymp)
export(sar_average)
export(sar_betap)
export(sar_chapman)
export(sar_countryside)
export(sar_epm1)
export(sar_epm2)
export(sar_gompertz)
export(sar_habitat)
export(sar_heleg)
export(sar_koba)
export(sar_linear)
export(sar_loga)
export(sar_logistic)
export(sar_mmf)
export(sar_monod)
export(sar_multi)
export(sar_negexpo)
export(sar_p1)
export(sar_p2)
export(sar_power)
export(sar_powerR)
export(sar_pred)
export(sar_ratio)
export(sar_threshold)
export(sar_weibull3)
export(sar_weibull4)
export(sars_models)
export(threshold_ci)
importFrom(AICcmodavg,AICc)
importFrom(cli,rule)
importFrom(cli,symbol)
importFrom(crayon,bold)
importFrom(crayon,col_align)
importFrom(crayon,cyan)
importFrom(crayon,green)
importFrom(crayon,red)
importFrom(crayon,yellow)
importFrom(doParallel,registerDoParallel)
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(grDevices,devAskNewPage)
importFrom(grDevices,n2mfrow)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,matlines)
importFrom(graphics,matplot)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,title)
importFrom(minpack.lm,nls.lm.control)
importFrom(minpack.lm,nlsLM)
importFrom(nortest,lillie.test)
importFrom(numDeriv,jacobian)
importFrom(parallel,makeCluster)
importFrom(parallel,stopCluster)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,cor.test)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,ks.test)
importFrom(stats,lm)
importFrom(stats,logLik)
importFrom(stats,nls)
importFrom(stats,numericDeriv)
importFrom(stats,optim)
importFrom(stats,predict)
importFrom(stats,printCoefmat)
importFrom(stats,pt)
importFrom(stats,qf)
importFrom(stats,quantile)
importFrom(stats,resid)
importFrom(stats,rmultinom)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,start)
importFrom(stats,summary.lm)
importFrom(stats,uniroot)
importFrom(utils,capture.output)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
